#!/bin/bash
#
#
# COPYRIGHT 2003-2010, EMULEX CORPORATION                               
# 3333 Susan St., Costa Mesa, CA 92626                                  
#                                                                         
# All rights reserved.  This computer program and related documentation 
# is protected by copyright  and distributed under licenses restricting 
# its use,  copying,  distribution  and decompilation.    This computer 
# program  and its  documentation  are CONFIDENTIAL  and a TRADE SECRET 
# of EMULEX CORPORATION.   The receipt or  possession of  this  program 
# or its documentation does not  convey rights to reproduce or disclose 
# its  contents,  or to  manufacture, use, or sell anything that it may 
# describe, in whole or in part,  without the specific  written consent 
# of  EMULEX CORPORATION.   Any reproduction  of  this program  without 
# the express  written  consent  of EMULEX  CORPORATION  is a violation 
# of the  copyright laws  and may  subject you to  criminal prosecution.


# Get environment data
OS=`uname -s`
Arch=`uname -m`
if [ "$Arch" = "i686" ] || [ "$Arch" = "i585" ];then
    Arch="i386"
fi
DIR=$(cd ${0%/*} ; pwd )

SUCCESS=0
FAILURE=1
LOGFILE_NAME="utils-install.log"
INSTALL_DIR="usr/sbin/ocmanager"
LOGFILE="/${INSTALL_DIR}/${LOGFILE_NAME}"
# Function:  log_message()
#
# Description:
#   Print the strings passed as parameters to both STDOUT as well as
#   to a log file.
#
# Parameters:
#   A series of strings.
#
# Returns:
#   0 on success.
log_message()
{
    local ECHO_OPTIONS
    LOGDIRECTORY=${LOGFILE%/*}
    if [ ! -d ${LOGDIRECTORY} ] ; then
        mkdir -p ${LOGDIRECTORY}
    fi

    if [ $# -eq 0 ] ; then
        echo "" | tee -a ${LOGFILE}
    elif [ -z "$1" ] ; then
        echo "" | tee -a ${LOGFILE}
    elif [ "$1" = "-init" ] ; then
        echo "$0 - $(date)" >> ${LOGFILE}
    else
        while [ -n "$1" ] ; do
            if [ "${1:0:1}" = "-" ] ; then
                ECHO_OPTIONS="${1}"
            else
                echo ${ECHO_OPTIONS} "$1" | tee -a ${LOGFILE}
            fi
            shift
        done
    fi
    return $SUCCESS
}

create_hbanyware_symlink()
{
    if [ -L /usr/sbin/hbanyware ] || [ -d /usr/sbin/hbanyware ]; then
        log_message "Cannot create /usr/sbin/hbanyware symbolic link!"
    else
        cd /usr/sbin; ln -s ocmanager hbanyware; cd - > /dev/null 2>&1
    fi
}

backup_hbanyware()
{
    if [ -L /usr/sbin/hbanyware ]; then	           # upgrade from OCM 5.1
        rm -rf /usr/sbin/hbanyware
    else
        if [ -d /usr/sbin/hbanyware ]; then        # upgrade from OCM 5.0
            log_message "Saving /usr/sbin/hbanyware as /usr/sbin/hbanyware.isave"
            rm -rf /usr/sbin/hbanyware.isave
            mv -f /usr/sbin/hbanyware /usr/sbin/hbanyware.isave
        fi
    fi
}

function postinstall {
	OCMPATH="/usr/sbin/ocmanager/stop_ocmanager"
	if [ -x "$OCMPATH" ]; then
		$OCMPATH
	fi
}

# Initialize the log file.
log_message -init


# Determine OS
if [ -f /etc/redhat-release ]; then
    citrixos=`cat /etc/redhat-release | cut -d' ' -f1`
    if [ "$citrixos" = "XenServer" ];then
        OS_VER="citrix"
    else
        rhel_major_version=`cat /etc/redhat-release | cut -d' ' -f7 | cut -d. -f1`
        rhel_minor_version=`cat /etc/redhat-release | cut -d' ' -f7 | cut -d. -f2`
        if [ "$rhel_major_version" -eq 5 ];then
            if [ "$rhel_minor_version" -lt 3 ];then
                log_message "This is not a supported version of Red Hat 5"
                log_message "Aborting installation."
                exit $FAILURE
            else
                OS_VER="rhel-5"
            fi
        elif [ "$rhel_major_version" -eq 6 ];then
            OS_VER="rhel-6"
        else
            log_message "This is not a supported version of Red Hat."
            log_message "Aborting installation."
            exit $FAILURE
        fi
    fi
elif [ -f /etc/SuSE-release ]; then
    sles_major_version=`cat /etc/SuSE-release | grep VERSION | awk '{ print $3 }'`
    sles_minor_version=`cat /etc/SuSE-release | grep PATCHLEVEL | awk '{ print $3 }'`
    if [ "$sles_major_version" -eq 10 ];then
        if [ "$sles_minor_version" -lt 2 ];then
           log_message "This is not a supported version of SuSE Linux Enterprise Server 10."
           log_message "Aborting installation."
           exit $FAILURE
        else
           OS_VER="sles-10"
        fi
    elif [ "$sles_major_version" -eq 11 ];then
        if [ "$sles_minor_version" -eq 0 ];then
            OS_VER="sles-11"
        elif [ "$sles_minor_version" -eq 1 ];then
            OS_VER="sles-11-sp1"
        else
           log_message "This is not a supported version of SuSE Linux Enterprise Server 11."
           log_message "Aborting installation."
           exit $FAILURE
        fi
    else
        log_message "This is not a supported version of SuSE Linux Enterprise Server."
        log_message "Aborting installation."
        exit $FAILURE
    fi
else
    log_message "ERROR: Cannot determine Linux distribution."
    log_message "Aborting installation."
    exit $FAILURE
fi

cd $DIR
if [ ! -d "${Arch}/${OS_VER}" ]; then
    log_message "This operating system is not supported by this $KITNAME Kit."
    log_message "Aborting installation."
    exit $FAILURE
else
    cd ${Arch}/${OS_VER}
fi


RPMHBAAPI=`ls elxocmlibhbaapi-*.rpm`
RPMCORE=`ls elxocmcore-*.rpm`
if [ -f elxocmgui-*.rpm ] && [ -f elxocmjvm-*.rpm ]; then
    RPMGUI=`ls elxocmgui-*.rpm`
    RPMJVM=`ls elxocmjvm-*.rpm`
    KITNAME="Enterprise"
else
    RPMGUI=""
    RPMJVM=""
    KITNAME="Core"
fi


log_message "Beginning OneCommand Manager $KITNAME Kit Installation..."


# Decide if libHBAAPI install is neccessary
HBAAPI_LIST=`ls elxocmlibhbaapi-*`
for hbaapi_rpm in $HBAAPI_LIST
do
    rpm -U --test --replacepkgs $hbaapi_rpm > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        
        RPMLIST="${hbaapi_rpm} ${RPMLIST}"
    fi
done

RPMLIST="$RPMLIST $RPMCORE $RPMJVM $RPMGUI"
for RPM in $RPMLIST
do
    log_message "Installing ./${Arch}/${OS_VER}/$RPM"
done
log_message ""
rpm -U --replacepkgs $RPMLIST 
STATUS=$?
if [ "$STATUS" != 0 ]; then
    log_message "OneCommand Manager $KITNAME Kit install failed."
    if [ -z "`rpm -qa | grep -i libnl`" ];then log_message "pre-reqs not met: libnl is not installed";fi
    exit $STATUS
fi


# obtain user selections for remote management
if [ "$KITNAME" = "Enterprise" ];then
    /${INSTALL_DIR}/set_operating_mode 45

    # remove script that changes operating mode if installer selects this option
    no_mode_change=`cat /etc/emulexDiscConfig | grep ClientOperationMode | grep locked`
    if [ -n "$no_mode_change" ];then
        rm -f /${INSTALL_DIR}/set_operating_mode
    fi
fi

backup_hbanyware
create_hbanyware_symlink
postinstall

log_message "OneCommand Manager $KITNAME Kit install completed successfully."
log_message ""
if [ "$KITNAME" = "Enterprise" ];then
    log_message "Type:    /${INSTALL_DIR}/ocmanager"
    log_message "to run the OneCommand Manager GUI client."
else
    log_message "Type:    /${INSTALL_DIR}/hbacmd"
    log_message "to run the OneCommand Manager CLI utility."
fi
log_message ""


exit $SUCCESS
  
